#
# spec file for package ghc-Glob
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name Glob
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.10.2
Release:        3.15
Summary:        Globbing library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/3.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-dlist-devel
BuildRequires:  ghc-dlist-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-compat-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
BuildRequires:  ghc-test-framework-quickcheck2-devel
BuildRequires:  ghc-test-framework-quickcheck2-prof
%endif

%description
A library for globbing: matching patterns against file paths.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal
chmod -x *.txt   # https://github.com/Deewiant/glob/issues/31

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE.txt

%files devel -f %{name}-devel.files
%doc CHANGELOG.txt README.txt

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE.txt

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Jan 15 2022 Peter Simons <psimons@suse.com>
- Update Glob to version 0.10.2 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Nov 20 2021 psimons@suse.com
- Update Glob to version 0.10.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Nov 11 2021 psimons@suse.com
- Update Glob to version 0.10.2.
  0.10.2, 2021-11-10:
  Relaxed transformers-compat version bound.
  Supported Win32 2.12.0.0 or higher.
* Tue Jul 27 2021 psimons@suse.com
- Update Glob to version 0.10.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Mon Jul 20 2020 psimons@suse.com
- Update Glob to version 0.10.1.
  0.10.1, 2020-07-19:
  Updated code and dependencies to support dlist-1.0.
  Cabal-Version minimum bumped to 1.10 as Hackage now rejects older minima.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Thu Dec 20 2018 psimons@suse.com
- Update Glob to version 0.10.0.
  0.10.0, 2018-12-19:
  Bug fix: "**/" matched hidden directories in some scenarios even when
  matchDotsImplicitly was set to False.
  Thanks to Travis Sunderland for the report as well as the fix.
* Thu Oct  4 2018 psimons@suse.com
- Update Glob to version 0.9.3.
  0.9.3, 2018-09-22:
  Updated dependencies to allow containers-0.7 (GHC 8.6). Thanks to
  chessai for the merge request.
  Updated tests to compile with GHC 8.6.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update Glob to version 0.9.2.
  Made Tests.Utils use Ints instead of Floats to avoid spurious failures
  that aren't of any concern.
  New functions, data types, and constants:
    System.FilePath.Glob.isLiteral :: Pattern -> Bool
    Tells whether a Pattern is a literal file path.
    Thanks to Simon Hengel and Harry Garrood for the
    feature request.
    System.FilePath.Glob.GlobOptions
    Options for the glob* family of IO functions.
    System.FilePath.Glob.globDefault :: GlobOptions
    Use matchDefault and don't return unmatched files.
  Changed function types:
    System.FilePath.Glob.globDir :: [Pattern] -> FilePath -> IO [[FilePath]]
    No longer returns unmatched paths, like globDir1.
    System.FilePath.Glob.globDirWith :: GlobOptions -> [Pattern] -> FilePath -> IO ([[FilePath]], Maybe [FilePath])
    Takes GlobOptions instead of MatchOptions, and returns
    unmatched paths in a Maybe corresponding to whether they
    were requested in the options or not.
    This is a significant performance boost for all glob*
    functions when unmatched file paths are not desired.
  Optimization: when unmatched file paths are not requested, glob and
    globDir1 use commonDirectory to avoid extra
    getDirectoryContents calls at the start.
  Optimization: character ranges containing . or / are simplified more
    than before, especially when they make the entire pattern
    incapable of matching anything.
  Optimization: extension separator matching where the extension is
    surrounded by other literals (e.g. "*.txt" or "foo.*" or
    simply "foo.txt") should be quicker in general, and the
    Patterns should be smaller. (This adds to the number of
    places where the code assumes that the extension separator
    is the '.' character.)
  Bug fix: commonDirectory should no longer add extra directory separators
    to the Pattern.
  Bug fix: the glob* functions should now place slashes correctly when
    using recursively matching patterns with extra slashes, such as
    "**//foo".
  Bug fix: number ranges are no longer optimized to single characters, so
    that leading zeroes are handled correctly: e.g. "<0-9>" didn't
    match "007".
  Bug fix: "//" did not match itself.
  Bug fix: ".//" did not match itself.
  Bug fix: "x" did not match ".//x" (with ignoreDotSlash enabled).
  Bug fix: "<-><->" matched single digit numbers.
  Bug fix: "<0-0><1-1>" didn't match "01".
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.8.0.
* Mon Jan  9 2017 psimons@suse.com
- Update to version 0.7.14 with cabal2obs.
* Tue Nov 29 2016 psimons@suse.com
- Update to version 0.7.13 with cabal2obs.
* Tue Oct 11 2016 psimons@suse.com
- Update to version 0.7.12 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 0.7.11 revision 0 with cabal2obs.
* Fri Jul 22 2016 psimons@suse.com
- Update to version 0.7.10 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.7.9 revision 0 with cabal2obs.
* Sun Jul  3 2016 mimi.vx@gmail.com
- update to 0.7.9
  * Add missing Utils module to test suite, so that the tests provided with
    the sdist tarball actually run.
  * Add dependency on transformers-compat to allow using
    Control.Monad.Trans.Except also with older library versions.
* Thu Jun 30 2016 mimi.vx@gmail.com
- update to 0.7.7
  * Update test dependencies to allow HUnit-1.3.
  * Update dependencies to allow filepath-1.4.
  * Added Cabal Source-Repository metadata, pointing to GitHub.
  * Integrated tests with Cabal so that they can be run with "cabal test".
  * Got rid of deprecation warnings by using Control.Monad.Trans.Except
    instead of Control.Monad.Trans.Error.
  * Added Semigroup instance, bringing in a new dependency on semigroups on
    pre-8.0 GHC versions.
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
